@@ -411,6 +411,7 @@ TYPES = [
     "course-of-action",
     "grouping",
     "identity",
+    "incident",
     "indicator",
     "infrastructure",
     "intrusion-set",
@@ -429,6 +430,7 @@ TYPES = [
     "sighting",
     "language-content",
     "marking-definition",
+    "extension-definition",
 ]
 
 OBSERVABLE_TYPES = [
@@ -484,6 +486,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'kill_chain_phases',
@@ -503,6 +506,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'aliases',
@@ -524,6 +528,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'action'
@@ -542,6 +547,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'context',
@@ -561,6 +567,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'roles',
@@ -568,13 +575,11 @@ PROPERTIES = {
         'sectors',
         'contact_information',
     ],
-    "indicator": [
+    "incident": [
         'type',
         'spec_version',
         'id',
         'created_by_ref',
-        "pattern_type",
-        "pattern_version",
         'created',
         'modified',
         'revoked',
@@ -584,10 +589,31 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
+        'name',
+        'description',
+    ],
+    "indicator": [
+        'type',
+        'spec_version',
+        'id',
+        'created_by_ref',
+        'created',
+        'modified',
+        'revoked',
+        'labels',
+        'confidence',
+        'lang',
+        'external_references',
+        'object_marking_refs',
+        'granular_markings',
+        'extensions',
         'name',
         'description',
         'indicator_types',
         'pattern',
+        "pattern_type",
+        "pattern_version",
         'valid_from',
         'valid_until',
         'kill_chain_phases',
@@ -607,6 +633,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'infrastructure_types',
@@ -628,6 +655,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'aliases',
@@ -653,6 +681,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'description',
         'latitude',
         'longitude',
@@ -678,6 +707,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'malware_types',
@@ -706,6 +736,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'product',
         'version',
         'host_vm_ref',
@@ -737,6 +768,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'abstract',
         'content',
         'authors',
@@ -756,6 +788,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'first_observed',
         'last_observed',
         'number_observed',
@@ -776,6 +809,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'explanation',
         'authors',
         'object_refs',
@@ -795,6 +829,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'report_types',
@@ -817,6 +852,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'threat_actor_types',
@@ -843,6 +879,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
         'tool_types',
@@ -864,6 +901,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'description',
     ],
@@ -886,6 +924,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'relationship_type',
         'description',
         'source_ref',
@@ -908,6 +947,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'first_seen',
         'last_seen',
         'count',
@@ -929,6 +969,7 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'object_ref',
         'object_modified',
         'contents',
@@ -943,10 +984,30 @@ PROPERTIES = {
         'external_references',
         'object_marking_refs',
         'granular_markings',
+        'extensions',
         'name',
         'definition_type',
         'definition',
-    ]
+    ],
+    "extension-definition": {
+        'type',
+        'spec_version',
+        'id',
+        'created_by_ref',
+        'created',
+        'modified',
+        'revoked',
+        'labels',
+        'external_references',
+        'object_marking_refs',
+        'granular_markings',
+        'name',
+        'description',
+        'schema',
+        'version',
+        'extension_types',
+        'extension_properties',
+    }
 }
 # Mappings of official Cyber Observable Objects to their official properties
 OBSERVABLE_PROPERTIES = {
@@ -1595,11 +1656,11 @@ OBSERVABLE_DICT_KEY_EXCEPTIONS = [
 # Reserved properties and objects
 RESERVED_PROPERTIES = [
     'severity',
-    'usernames',
+    'username',
     'phone_numbers',
+    'action',
 ]
 RESERVED_OBJECTS = [
-    'incident',
     'action',
 ]
 OBSERVABLE_RESERVED_OBJECTS = [
@@ -1613,6 +1674,7 @@ NON_SDOS = [
     'marking-definition',
     'sighting',
     'relationship',
+    'extension-definition',
 ]
 
 # List of relationship types common to all object types
@@ -2120,6 +2182,9 @@ CHECK_CODES = {
     '302': 'extref-hashes',
     '303': 'indicator-properties',
     '304': 'deprecated-properties',
+    '305': 'extension-description',
+    '306': 'extension-properties',
+    '401': 'extensions-use',
 }
 
 
